@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::Struct::Tag;
-$XML::Grammar::Fiction::Struct::Tag::VERSION = '0.28.0';
+$XML::Grammar::Fiction::Struct::Tag::VERSION = '0.28.1';
 use strict;
 use warnings;
 
@@ -17,6 +17,13 @@ has 'children' => (
     isa => "Maybe[ArrayRef]",
 );
 
+sub line_idx
+{
+    my ( $self, ) = @_;
+
+    return $self->line();
+}
+
 sub append_children
 {
     my ( $self, $children ) = @_;
@@ -51,7 +58,7 @@ sub detach_children
 }
 
 package XML::Grammar::Fiction::Struct::Tag::Para;
-$XML::Grammar::Fiction::Struct::Tag::Para::VERSION = '0.28.0';
+$XML::Grammar::Fiction::Struct::Tag::Para::VERSION = '0.28.1';
 use MooX 'late';
 
 extends("XML::Grammar::Fiction::Struct::Tag");
@@ -74,7 +81,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.28.0
+version 0.28.1
 
 =head1 METHODS
 
@@ -86,6 +93,10 @@ The tag's name.
 
 The tag's line number.
 
+=head2 $self->line_idx()
+
+The tag's line number.
+
 =head2 $self->is_standalone()
 
 Determines whether it's a standalone tag or not. (if it's an opening tag).
