@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::Event;
-$XML::Grammar::FictionBase::Event::VERSION = '0.28.0';
+$XML::Grammar::FictionBase::Event::VERSION = '0.28.1';
 
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ has 'type' => ( isa => "Str", is => "ro" );
 has 'tag' => ( isa => "Maybe[Str]", is => "ro", predicate => '_has_tag', );
 has 'elem' =>
     ( isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro" );
+has 'line_idx' => ( isa => "Maybe[Int]", is => "ro" );
 has 'tag_elem' =>
     ( isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro" );
 
@@ -52,7 +53,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.28.0
+version 0.28.1
 
 =head1 SLOTS
 
@@ -87,6 +88,10 @@ Returns true if the $event 's type is "open".
 
 Returns true if the $event 's type is either "open" or "close".
 
+=head2 $event->line_idx()
+
+Returns an optional line number.
+
 =head2 $self->meta()
 
 Leftover from Moo.
